Package: workloopR
Type: Package
Title: Analysis of Work Loops and Other Data from Muscle Physiology
        Experiments
Version: 1.1.4
Authors@R: 
    c(person(given = "Vikram B.",
             family = "Baliga", 
             role = c("aut", "cre"),
             email = "vbaliga87@gmail.com",
             comment = c(ORCID = "0000-0002-9367-8974")),
      person(given = "Shreeram", 
             family = "Senthivasan",
             role = "aut",
             email = "shreeramsenthi@gmail.com",
             comment = c(ORCID = "0000-0002-7118-9547")),
      person(given = "Julia",
             family = "Romanowska",
             role = "rev",
             email = "Julia.Romanowska@uib.no",
             comment = "Julia reviewed the package for rOpenSci
             , see <https://github.com/ropensci/software-review/issues/326/>"),
      person(given = "Eric",
             family = "Brown", 
             role = "rev",
             email = "eb@ericebrown.com",
             comment = "Eric reviewed the package for rOpenSci
             , see <https://github.com/ropensci/software-review/issues/326/>"))
Description: Functions for the import, transformation, and analysis of data 
    from muscle physiology experiments. The work loop technique is used to 
    evaluate the mechanical work and power output of muscle. Josephson (1985) 
    <doi:10.1242/jeb.114.1.493> modernized the technique for
    application in comparative biomechanics. Although our initial motivation 
    was to provide functions to analyze work loop experiment data, as we 
    developed the package we incorporated the ability to analyze data from 
    experiments that are often complementary to work loops. There are currently 
    three supported experiment types: work loops, simple twitches, and tetanus 
    trials. Data can be imported directly from .ddf files or via an object 
    constructor function. Through either method, data can then be cleaned or 
    transformed via methods typically used in studies of muscle physiology. 
    Data can then be analyzed to determine the timing and magnitude of force 
    development and relaxation (for isometric trials) or the magnitude of work, 
    net power, and instantaneous power among other things (for work loops). 
    Although we do not provide plotting functions, all resultant objects are 
    designed to be friendly to visualization via either base-R plotting or 
    'tidyverse' functions.
 This package has been peer-reviewed by rOpenSci (v. 1.1.0).
URL: https://docs.ropensci.org/workloopR/,
        https://github.com/ropensci/workloopR/
BugReports: https://github.com/ropensci/workloopR/issues/
Imports: pracma (>= 2.0.7), signal (>= 0.7-6)
Suggests: testthat (>= 2.1.1), knitr, rmarkdown, dplyr, ggplot2,
        magrittr, purrr, tidyr
License: GPL (>= 3)
Encoding: UTF-8
RoxygenNote: 7.1.1.9000
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2021-05-05 01:12:54 UTC; vbali
Author: Vikram B. Baliga [aut, cre] (<https://orcid.org/0000-0002-9367-8974>),
  Shreeram Senthivasan [aut] (<https://orcid.org/0000-0002-7118-9547>),
  Julia Romanowska [rev] (Julia reviewed the package for rOpenSci , see
    <https://github.com/ropensci/software-review/issues/326/>),
  Eric Brown [rev] (Eric reviewed the package for rOpenSci , see
    <https://github.com/ropensci/software-review/issues/326/>)
Maintainer: Vikram B. Baliga <vbaliga87@gmail.com>
Repository: CRAN
Date/Publication: 2021-05-06 08:10:02 UTC
Built: R 4.6.0; ; 2026-04-25 23:09:38 UTC; unix
