# Generated by roxygen2: do not edit by hand

S3method(print,analyzed_workloop)
S3method(print,muscle_stim)
S3method(summary,analyzed_workloop)
S3method(summary,muscle_stim)
S3method(summary,tetanus)
S3method(summary,workloop)
export(analyze_workloop)
export(as_muscle_stim)
export(fix_GR)
export(get_wl_metadata)
export(invert_position)
export(isometric_timing)
export(read_analyze_wl)
export(read_analyze_wl_dir)
export(read_ddf)
export(read_ddf_dir)
export(select_cycles)
export(summarize_wl_trials)
export(time_correct)
export(trapezoidal_integration)
